#!/bin/bash

check_status() {
  if [ $? -eq 0 ]; then
    echo OK
  else
    echo >&2 '
****************
***** FAIL *****
****************
    '
    exit 1
  fi
}

# If the software is already running on the camera, stop it
echo "Stopping active Trueface services"
test -e /etc/init.d/S98trueface && /etc/init.d/S98trueface stop || true
check_status

# Allow 5 seconds for the S98trueface service to stop,
# may need to do some cleanup after stop command issued
sleep 5

# Move the script for starting the service
echo "Creating service to start application on boot"
chmod 775 S98trueface
cp ./S98trueface /etc/init.d
check_status

# Move the executable to /mnt/data and create symbolic link to /usr/local/bin
echo "Installing main application to /usr/local/bin/"
cp ./trueface_temp_reader /mnt/data/
test -e /usr/local/bin/trueface_temp_reader || ln -s /mnt/data/trueface_temp_reader /usr/local/bin/trueface_temp_reader
check_status

# Remove the config server if it was previously installed
echo "Performing cleanup"
test -e /usr/local/bin/trueface_config_server && rm /usr/local/bin/trueface_config_server || true
test -e /mnt/data/trueface_config_server && rm /mnt/data/trueface_config_server || true
# Delete the previous log files
test -e /var/trueface_logs && rm -r /var/trueface_logs || true
check_status

# Disable the CNN model (otherwise face detection is slow)
echo "Disabling CNN"
/usr/local/bin/set_cnn.sh enable 0
check_status

# Disable the thermal overlay
echo "Disabling thermal overlay"
test -e /usr/local/bin/thermal_overlay && mv /usr/local/bin/thermal_overlay /usr/local/bin/thermal_overlay.old || true
check_status

# Disable auto flip
echo "Disabling auto flip"
test -e /usr/local/bin/check_imager_orientation.sh && mv /usr/local/bin/check_imager_orientation.sh /usr/local/bin/check_imager_orientation.sh.old || true
check_status

# Create directory for saving logs
echo "Creating directory for log files at /var/trueface_logs/"
test -e /var/trueface_logs/ || mkdir /var/trueface_logs/
check_status

echo >&2 '
*******************
***** SUCCESS *****
*******************
'
echo "Rebooting in 3 seconds..."
sleep 1
echo "Rebooting in 2 seconds..."
sleep 1
echo "Rebooting in 1 second..."
sleep 1
reboot